==> applet-service-1.0.2-20190424.103239-25-sources.jar: com/bizvane/appletservice/models/bo/AppletWxPayBo.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;

public class AppletWxPayBo {
    private Long sysBrandId;
    private String memberCode;
    private Double money;
    private Date paymentDate;
    private String bizvaneSessionId;
    private String openId;
    private String appId;
    private Double giveMoney;

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Double getMoney() {
        return money;
    }

    public void setMoney(Double money) {
        this.money = money;
    }

    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }

    public String getBizvaneSessionId() {
        return bizvaneSessionId;
    }

    public void setBizvaneSessionId(String bizvaneSessionId) {
        this.bizvaneSessionId = bizvaneSessionId;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Double getGiveMoney() {
        return giveMoney;
    }

    public void setGiveMoney(Double giveMoney) {
        this.giveMoney = giveMoney;
    }
}

==> applet-service-1.0.2-20190711.022322-33-sources.jar: com/bizvane/appletservice/models/bo/AppletWxPayBo.java <==
package com.bizvane.appletservice.models.bo;

import java.util.Date;

public class AppletWxPayBo {
    private Long sysBrandId;
    private String memberCode;
    private Double money;
    private Date paymentDate;
    private String bizvaneSessionId;
    private String openId;
    private String appId;
    private Double giveMoney;
    private String wxPayVoucherNo;

    public String getWxPayVoucherNo() {
        return wxPayVoucherNo;
    }

    public void setWxPayVoucherNo(String wxPayVoucherNo) {
        this.wxPayVoucherNo = wxPayVoucherNo;
    }

    public Long getSysBrandId() {
        return sysBrandId;
    }

    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    public String getMemberCode() {
        return memberCode;
    }

    public void setMemberCode(String memberCode) {
        this.memberCode = memberCode;
    }

    public Double getMoney() {
        return money;
    }

    public void setMoney(Double money) {
        this.money = money;
    }

    public Date getPaymentDate() {
        return paymentDate;
    }

    public void setPaymentDate(Date paymentDate) {
        this.paymentDate = paymentDate;
    }

    public String getBizvaneSessionId() {
        return bizvaneSessionId;
    }

    public void setBizvaneSessionId(String bizvaneSessionId) {
        this.bizvaneSessionId = bizvaneSessionId;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getAppId() {
        return appId;
    }

    public void setAppId(String appId) {
        this.appId = appId;
    }

    public Double getGiveMoney() {
        return giveMoney;
    }

    public void setGiveMoney(Double giveMoney) {
        this.giveMoney = giveMoney;
    }
}
